@@ -186,9 +186,9 @@ gnome_canvas_hacktext_init (GnomeCanvasHacktext *hacktext)
 	hacktext->text = NULL;
 	hacktext->priv = g_new (GnomeCanvasHacktextPriv, 1);
 	hacktext->priv->font = NULL;
-	hacktext->priv->affine[0] = hacktext->priv->affine[3] = 1.0;
-	hacktext->priv->affine[1] = hacktext->priv->affine[2] =
-	  hacktext->priv->affine[4] = hacktext->priv->affine[5] = 0.0;
+
+	art_affine_identity (hacktext->priv->affine);
+
 	for (i = 0; i < 256; i++)
 		hacktext->priv->info[i].bpath = NULL;
 }
@@ -238,8 +238,7 @@ art_drect_hacktext (ArtDRect *bbox, GnomeCanvasHacktext *hacktext)
 	if (text == NULL)
 		return;
 
-	affine[0] = affine[3] = 1.0;
-	affine[1] = affine[2] = affine[4] = affine[5] = 0.0;
+	art_affine_identity (affine);
 
 	art_affine_scale (affine, hacktext->size * 0.001, hacktext->size * -0.001);	
 	affine[4] = x;
@@ -304,7 +303,7 @@ get_bounds_canvas (GnomeCanvasHacktext *hacktext, double *bx1, double *by1, doub
 
 	get_bounds (hacktext, &bbox_world.x0, &bbox_world.y0, &bbox_world.x1, &bbox_world.y1);
 
-	//art_drect_affine_transform (&bbox_canvas, &bbox_world, affine);
+	/* art_drect_affine_transform (&bbox_canvas, &bbox_world, affine);  */
 	/* include 1 pixel of fudge */
 	*bx1 = bbox_canvas.x0 - 1;
 	*by1 = bbox_canvas.y0 - 1;
