@@ -758,8 +758,9 @@ gpp_show (GnomePrintContext *pc, char const *text)
 	 * with the translation already done for the new
 	 * Postscript->Canvas translation
 	 */
-	p.x = g->bpath->bpath [0].x3;
-	p.y = g->bpath->bpath [0].y3;
+	
+	p.x = g->bpath->bpath [g->bpath->n_bpath - 1].x3;
+	p.y = g->bpath->bpath [g->bpath->n_bpath - 1].y3;
 
 	/*
 	 * Flip the angle
@@ -841,6 +842,9 @@ gpp_finalize (GtkObject *object)
 		page = g_array_index (priv->pages, GnomeCanvasItem *, i);
 		gtk_object_destroy (GTK_OBJECT (page));
 	}
+
+	gtk_object_destroy (GTK_OBJECT (priv->page));
+	gtk_object_destroy (GTK_OBJECT (priv->root));
 	
 	g_array_free (priv->pages, TRUE);
 
