@@ -244,10 +244,14 @@ gnome_print_ps_setfont_raw (GnomePrintContext *pc, GnomeFontUnsized *unsized,
 	}
     }
 
-  if (ps->current_font && strcmp (ps->current_font, fontname) == 0 &&
-      ps->current_font_size == size)
-    return 0; /* this font is already set */
-
+  /* NOT always true because of grestore and gsave. Should use
+     a flag to set if grestore has been used **/  
+#if 0
+          if (ps->current_font && strcmp (ps->current_font, fontname) == 0 &&
+              ps->current_font_size == size)
+                  return 0; /* this font is already set */
+#endif
+          
   ps->current_font = fontname;
   ps->current_font_size = size;
   /* FIXME: what about ->current_gnome_font?  */
@@ -352,7 +356,11 @@ gnome_print_ps_show (GnomePrintContext *pc, char const *text)
 	  c = gnome_font_get_glyph (ps->current_gnome_font,
 				    (unsigned char)(text[i]));
 	  if (c == -1)
-	    c = '*'; /* FIXME -- do something better for missing chars.  */
+          {
+                  c = '*'; /* FIXME -- do something better for missing chars.  */
+                  g_print("\n*** Gnome-Print: gnome-print-ps.c  non-standard Char = %i\n", (unsigned char)text[i]);
+          }
+          
 	  if (gnome_print_context_fprintf (pc, "%c", c) < 0)
 	    return -1;
 	}
